@@ -40,7 +40,7 @@ enum Sink {
 
     #[cfg(feature = "kafkasink")]
     Kafka(KafkaConfig),
-    
+
     #[cfg(feature = "elasticsink")]
     Elastic(ElasticConfig),
 }
@@ -52,7 +52,7 @@ impl SinkConfig for Sink {
 
             #[cfg(feature = "kafkasink")]
             Sink::Kafka(c) => c.bootstrap(input),
-            
+
             #[cfg(feature = "elasticsink")]
             Sink::Elastic(c) => c.bootstrap(input),
         }
@@ -81,7 +81,7 @@ impl ConfigRoot {
         }
 
         // finally, we use env vars to make some last-step overrides
-        s.merge(Environment::with_prefix("OURA"))?;
+        s.merge(Environment::with_prefix("OURA").separator("_"))?;
 
         s.try_into()
     }
