@@ -264,7 +264,7 @@ impl EventSource for TransactionBodyComponent {
             }
             TransactionBodyComponent::Certificates(certs) => {
                 for cert in certs.iter() {
-                    cert.write_events(&writer)?;
+                    cert.write_events(writer)?;
                 }
             }
             TransactionBodyComponent::Mint(mint) => {
@@ -330,7 +330,7 @@ impl EventSource for TransactionBody {
 
         // write sub-events
         for component in self.iter() {
-            component.write_events(&writer)?;
+            component.write_events(writer)?;
         }
 
         Ok(())
@@ -342,6 +342,7 @@ impl EventSource for Block {
         let writer = writer.child_writer(EventContext {
             block_number: Some(self.header.header_body.block_number),
             slot: Some(self.header.header_body.slot),
+            timestamp: writer.compute_timestamp(self.header.header_body.slot),
             ..EventContext::default()
         });
 
